/*******************************************************************************
  MPLAB Harmony Application Source File
  
  Company:
    Microchip Technology Inc.
  
  File Name:
    app.c

  Summary:
    This file contains the source code for the MPLAB Harmony application.

  Description:
    This file contains the source code for the MPLAB Harmony application.  It 
    implements the logic of the application's state machine and it may call 
    API routines of other MPLAB Harmony modules in the system, such as drivers,
    system services, and middleware.  However, it does not call any of the
    system interfaces (such as the "Initialize" and "Tasks" functions) of any of
    the modules in the system or make any assumptions about when those functions
    are called.  That is the responsibility of the configuration-specific system
    files.
 *******************************************************************************/

// DOM-IGNORE-BEGIN
/*******************************************************************************
Copyright (c) 2013-2014 released Microchip Technology Inc.  All rights reserved.

Microchip licenses to you the right to use, modify, copy and distribute
Software only when embedded on a Microchip microcontroller or digital signal
controller that is integrated into your product or third party product
(pursuant to the sublicense terms in the accompanying license agreement).

You should refer to the license agreement accompanying this Software for
additional information regarding your rights and obligations.

SOFTWARE AND DOCUMENTATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND,
EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF
MERCHANTABILITY, TITLE, NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE.
IN NO EVENT SHALL MICROCHIP OR ITS LICENSORS BE LIABLE OR OBLIGATED UNDER
CONTRACT, NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR
OTHER LEGAL EQUITABLE THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES
INCLUDING BUT NOT LIMITED TO ANY INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE OR
CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST DATA, COST OF PROCUREMENT OF
SUBSTITUTE GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY THIRD PARTIES
(INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.
 *******************************************************************************/
// DOM-IGNORE-END


// *****************************************************************************
// *****************************************************************************
// Section: Included Files 
// *****************************************************************************
// *****************************************************************************

#include "app.h"


#include "stdio.h"

char Buf[32];
int delay_Clock = 200000000;
APP_DATA     appData;
SYS_FS_HANDLE   my_fileHandle; //t@Cnh
bool Flag_SdConnected;  
int Num0;  //SDJ[hE

void delay_us(volatile unsigned int usec)        //1secx
{
        volatile  int count;

        count = (int)(delay_Clock/20000000)*usec;


        do      //@at@200MH (Clock=200000000)
        {       //delay_us(1000)F1000.4sec  delay_us(100)F100.6sec  delay_us(10):10.5sec@@delay_us(1)F1.5sec
                asm("NOP"); asm("NOP"); asm("NOP"); asm("NOP"); asm("NOP");asm("NOP");
                asm("NOP"); asm("NOP"); asm("NOP"); asm("NOP"); asm("NOP"); asm("NOP");

                count--;
        }while(count != 0);
}



void delay_ms(volatile unsigned int msec)        //1msecx
{
        volatile unsigned int i;         //Fat200MH (Clock=200000000)//delay_ms(1)F 1.0006msec   delay_ms(100)F100.04msec

        for(i=0; i<msec; i++)
        delay_us(1000);
}



void APP_SYSFSEventHandler(SYS_FS_EVENT event, void * eventData, uintptr_t context) //SDJ[h̃}EgL𒲂ׂR[obN֐
{
    switch(event)
    {
        /* If the event is mount then check which media has been mounted */
        case SYS_FS_EVENT_MOUNT:    
            if(0 == strcmp((const char *)eventData,"/mnt/myDrive1"))
            {
                Flag_SdConnected = true;
                LATDbits.LATD0 = 1;
            }

            break;
        /* If the event is unmount then check which media has been unmount */
        case SYS_FS_EVENT_UNMOUNT:
            if(0 == strcmp((const char *)eventData,"/mnt/myDrive1"))
            {
                Flag_SdConnected = false; 
                 LATDbits.LATD0 = 0;
            }

            break;
            
        case SYS_FS_EVENT_ERROR:
            break; 
            
        default:
            break;
    }
}

void APP_SdMtCheck(void)
{
    /* Set the event handler*/
    SYS_FS_EventHandlerSet(APP_SYSFSEventHandler, (uintptr_t)NULL); //SDJ[h̃}EgL𒲂ׂR[obN֐Zbg
}

void APP_SdTasks(void)
{
    SYS_FS_RESULT result = SYS_FS_RES_FAILURE;
    /* The application task state machine */
    switch(appData.state)
    {
        case APP_OPEN_FILE:
            /* Wait until MSD is mounted and file search is sucessful */
            if(Flag_SdConnected == true)
            {
                 // t@C݃[hŃI[v At@CȂΐVKt@C쐬

                my_fileHandle = SYS_FS_FileOpen("myTestData.txt", (SYS_FS_FILE_OPEN_WRITE));
                if(my_fileHandle == SYS_FS_HANDLE_INVALID)
                { //t@CI[vG[̏ꍇ
                    lcd_cmd(0x80);          //1ڂ̐擪
                    sprintf(Buf,"FileOpen_w@failed     ");//
                    lcd_str(Buf);                   //t\
                    while(1);
                }
                else
                {
                    SYS_FS_FileClose(my_fileHandle);
                    
                    Num0++;
                
                    lcd_cmd(0x80);          //1ڂ̐擪
                    sprintf(Buf,"FileOpen_w  OK !!        ");    //t"W_ModeOpen OK" \
                    lcd_str(Buf);                   //t\
                    lcd_cmd(0xC0);          //Qsڂ̐擪
                    sprintf(Buf,"Num0=%d                ", Num0);       //ysNumFSDJ[hE
                    lcd_str(Buf);           // JnbZ[W2sڕ\
                
                    appData.state = APP_IDLE;
                }
            }
            break;
            
        case APP_IDLE:
            LATAbits.LATA14 = 1;
            if(Flag_SdConnected == false)  //SDJ[h𔲂Ɓ@}o҂[hɈڍsB
            {
               appData.state = APP_OPEN_FILE;
            }
            else
            {
            }  
            break;
            
        default:
            break;
    }
} 





// *****************************************************************************
// *****************************************************************************
// Section: Global Data Definitions
// *****************************************************************************
// *****************************************************************************

// *****************************************************************************
/* Application Data

  Summary:
    Holds application data

  Description:
    This structure holds the application's data.

  Remarks:
    This structure should be initialized by the APP_Initialize function.
    
    Application strings and buffers are be defined outside this structure.
*/

APP_DATA appData;

// *****************************************************************************
// *****************************************************************************
// Section: Application Callback Functions
// *****************************************************************************
// *****************************************************************************

/* TODO:  Add any necessary callback functions.
*/

// *****************************************************************************
// *****************************************************************************
// Section: Application Local Functions
// *****************************************************************************
// *****************************************************************************


/* TODO:  Add any necessary local functions.
*/


// *****************************************************************************
// *****************************************************************************
// Section: Application Initialization and State Machine Functions
// *****************************************************************************
// *****************************************************************************

/*******************************************************************************
  Function:
    void APP_Initialize ( void )

  Remarks:
    See prototype in app.h.
 */

void APP_Initialize ( void )
{
    /* Place the App state machine in its initial state. */
    appData.state = APP_STATE_INIT;

    
    /* TODO: Initialize your application's state machine and other
     * parameters.
     */
    
     
    appData.state = APP_OPEN_FILE;
    
    
    lcd_init();				// LCD
    lcd_cmd(0b00001100);    // J[\:OFF  uݸ:OFF
    
    lcd_clear();            // S

    lcd_cmd(0x80);          //1sڂ̐擪
    sprintf(Buf,"PIC32MZ    SD      ");   //t@C@//󔒕K{
    lcd_str(Buf);           // JnbZ[W1sڕ\
    lcd_cmd(0xC0);          //Qsڂ̐擪
    sprintf(Buf,"File OpenClose     ");	//^b`YW\
    lcd_str(Buf);           // JnbZ[W2sڕ\
                    
    delay_ms(2000); 
}


/******************************************************************************
  Function:
    void APP_Tasks ( void )

  Remarks:
    See prototype in app.h.
 */

void APP_Tasks ( void )
{
    APP_SdMtCheck();    //SDJ[h̃}Eg`FbN 
    APP_SdTasks();      //SDJ[h̃C^XN
}

 

/*******************************************************************************
 End of File
 */
